@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    Copyright 2010 cloudControl UG (haftungsbeschraenkt)
+    Copyright 2014 cloudControl GmbH
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -21,8 +21,14 @@ from cctrl.version import __version__
 HOME_PATH = os.path.abspath(os.path.expanduser('~/.cloudControl'))
 TOKEN_FILE_NAME = os.environ.get('CCTRL_TOKEN_FILE', 'token.json')
 TOKEN_FILE_PATH = os.path.join(HOME_PATH, TOKEN_FILE_NAME)
-CACHE_DIR = None
 VERSION = __version__
-SSH_FORWARDER = os.environ.pop('SSH_FORWARDER', 'ssh.cloudcontrolled.net')
-SSH_FORWARDER_PORT = '2222'
 CONFIG_ADDON = os.getenv('CONFIG_ADDON', 'config.free')
+
+
+class Settings():
+
+    def __init__(self, api_url=None, token_source_url=None, ssh_forwarder_url=None, env=os.environ):
+        self.ssh_forwarder = ssh_forwarder_url or env.pop('SSH_FORWARDER', 'sshforwarder.cloudcontrolled.com')
+        self.ssh_forwarder_port = '2222'
+        self.api_url = api_url or env.pop('CCTRL_API_URL', 'https://api.cloudcontrol.com')
+        self.token_source_url = token_source_url or self.api_url + '/token/'
